==> fantacalciobazar_0.5.tar.gz: fantacalciobazar/login.php <==
<?php

##################################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################


$parla = "NO";
if ($cambia_pass) $parla = "SI";
include("./controlla_pass.php");
include("$percorso_cartella_dati/head.php");

if ($cambia_pass) {

if ($pass_errata == "SI") { $cambiare = "NO"; }
if ($nome_utente == "admin") {
if ($pass_admin_errata == "NO") $cambiare = "SI";
} # fine if ($nome_utente == "admin")
if ($nuova_pass1 != $nuova_pass2 and $cambiare != "NO") {
echo "Le nuove password non coincidno.<br>";
$cambiare = "NO";
} # fine if ($nuova_pass1 != $nuova_pass2 and ...)

if ($cambiare != "NO") {
if ($nuova_pass1 == "") $nuova_pass1 = "nopasswordinserita";
$lock = fopen("$percorso_cartella_dati/pass.lock","w+");
flock($lock,2);
$linee_pass = file("$percorso_cartella_dati/dati.php");
$filepass = fopen("$percorso_cartella_dati/dati.php","w+");
flock($filepass,2);
$num_linee_pass = count($linee_pass);
$lung_nome_utente = strlen($nome_utente) + 3;
for ($num1 = 0 ; $num1 < $num_linee_pass; $num1++) {
if ($nome_utente == "admin") {
$stringa = substr($linee_pass[$num1],0,10);
if ($stringa == "\$passadmin") {
$linee_pass[$num1] = "\$passadmin = \"$nuova_pass1\";
";
break;
} # fine if ($stringa == $nome_utente."]")
} # fine if ($nome_utente == "admin")
else {
$stringa = substr($linee_pass[$num1],6,$lung_nome_utente);
if ($stringa == "\"".$nome_utente."\"]") {
$linee_pass[$num1] = "\$pass[\"$nome_utente\"] = \"$nuova_pass1\";
";
break;
} # fine if ($stringa == $nome_utente."]")
} # fine else if ($nome_utente == "admin")
} # fine for $num1
rewind($filepass);
for ($num1 = 0 ; $num1 < $num_linee_pass; $num1++) {
fwrite($filepass,$linee_pass[$num1]);
} # fine for $num1
flock($filepass,3);
flock($lock,3);
echo "Password cambiata.<br>";
} # fine if ($cambiare != "NO")

echo "<form method=\"post\" action=\"login.php\">
<input type=\"submit\" name=\"torna\" value=\"Torna indietro\">
</form>";

} # fine if ($cambia_pass)


else {

include("$percorso_cartella_dati/dati.php");
$pass = "";
$passadmin = "";

echo "<center><font size=+2>Bazar del fantacalcio</font>";
if ($mostra_giornate_in_login == "SI") {
echo "<form method=\"post\" action=\"guarda_giornata.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"origine\" value=\"login.php\">
<input type=\"submit\" name=\"guarda_giornata\" value=\"Guarda la giornata\">
 n <select name=\"giornata\">
<option value=\"\">--</option>";
for ($num1 = "01" ; $num1 < 100 ; $num1++) {
if (strlen($num1) == 1) $num1 = "0".$num1;
$giornata = "giornata$num1";
if (is_file("$percorso_cartella_dati/$giornata")) {
echo "<option value=\"giornata$num1\">$num1</option>";
} # fine if (is_dir($giornata))
else break;
} # fine for $num1
echo "</select></form>";
} # fine if ($mostra_giornate_in_login == "SI")
echo "</center><form method=\"post\" action=\"mercato.php\">
Nome utente: <input type=\"text\" name=\"nome_utente\" size=\"12\"><br>
Password: <input type=\"password\" name=\"pass_fornita\" size=\"9\"><br>
<input type=\"submit\" name=\"accedi\" value=\"Accedi\">
</form><hr width=\"95%\">
<form method=\"post\" action=\"login.php\">
Nome utente: <input type=\"text\" name=\"nome_utente\" size=\"12\"><br>
Vecchia password: <input type=\"password\" name=\"pass_fornita\" size=\"9\"><br>
Nuova password: <input type=\"password\" name=\"nuova_pass1\" size=\"9\"><br>
Ripeti la nuova password: <input type=\"password\" name=\"nuova_pass2\" size=\"9\"><br>
<input type=\"submit\" name=\"cambia_pass\" value=\"Cambia la password\">
 (non utilizzate una vostra password abituale, la potremo vedere)</form>";


} # fine else if ($cambia_pass)

include("$percorso_cartella_dati/foot.php");
?>

==> fantacalciobazar_0.5.5.tar.gz: fantacalciobazar/login.php <==
<?php

##################################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001-2014 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################


include('./include/funzioni.php');
$parla = "NO";
if ($cambia_pass) $parla = "SI";
include("./controlla_pass.php");
include("$percorso_cartella_dati/head.php");

if ($cambia_pass) {

if ($pass_errata == "SI") { $cambiare = "NO"; }
if ($nome_utente == "admin") {
if ($pass_admin_errata == "NO") $cambiare = "SI";
} # fine if ($nome_utente == "admin")
if ($nuova_pass1 != $nuova_pass2 and $cambiare != "NO") {
echo "Le nuove password non coincidno.<br>";
$cambiare = "NO";
} # fine if ($nuova_pass1 != $nuova_pass2 and ...)

if ($cambiare != "NO") {
if ($nuova_pass1 == "") $nuova_pass1 = "nopasswordinserita";
$lock = fopen("$percorso_cartella_dati/pass.lock","w+");
flock($lock,2);
$linee_pass = file("$percorso_cartella_dati/dati.php");
$filepass = fopen("$percorso_cartella_dati/dati.php","w+");
flock($filepass,2);
$num_linee_pass = count($linee_pass);
$lung_nome_utente = strlen($nome_utente) + 3;
for ($num1 = 0 ; $num1 < $num_linee_pass; $num1++) {
if ($nome_utente == "admin") {
$stringa = substr($linee_pass[$num1],0,10);
if ($stringa == "\$passadmin") {
$linee_pass[$num1] = "\$passadmin = \"$nuova_pass1\";
";
break;
} # fine if ($stringa == $nome_utente."]")
} # fine if ($nome_utente == "admin")
else {
$stringa = substr($linee_pass[$num1],6,$lung_nome_utente);
if ($stringa == "\"".$nome_utente."\"]") {
$linee_pass[$num1] = "\$pass[\"$nome_utente\"] = \"$nuova_pass1\";
";
break;
} # fine if ($stringa == $nome_utente."]")
} # fine else if ($nome_utente == "admin")
} # fine for $num1
rewind($filepass);
for ($num1 = 0 ; $num1 < $num_linee_pass; $num1++) {
fwrite($filepass,$linee_pass[$num1]);
} # fine for $num1
flock($filepass,3);
flock($lock,3);
echo "Password cambiata.<br>";
} # fine if ($cambiare != "NO")

echo "<form  accept-charset=\"utf-8\" method=\"post\" action=\"login.php\">
<input type=\"submit\" name=\"torna\" value=\"Torna indietro\">
</form>";

} # fine if ($cambia_pass)


else {

include("$percorso_cartella_dati/dati.php");
$pass = "";
$passadmin = "";

echo "<center><font size=+2>Bazar del fantacalcio</font>";
if ($mostra_giornate_in_login == "SI") {
echo "<form  accept-charset=\"utf-8\" method=\"post\" action=\"guarda_giornata.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"origine\" value=\"login.php\">
<input type=\"submit\" name=\"guarda_giornata\" value=\"Guarda la giornata\">
 n° <select name=\"giornata\">
<option value=\"\">--</option>";
for ($num1 = "01" ; $num1 < 100 ; $num1++) {
if (strlen($num1) == 1) $num1 = "0".$num1;
$giornata = "giornata$num1";
if (is_file("$percorso_cartella_dati/$giornata")) {
echo "<option value=\"giornata$num1\">$num1</option>";
} # fine if (is_dir($giornata))
else break;
} # fine for $num1
echo "</select></form>";
} # fine if ($mostra_giornate_in_login == "SI")
echo "</center><form  accept-charset=\"utf-8\" method=\"post\" action=\"mercato.php\">
Nome utente: <input type=\"text\" name=\"nome_utente\" size=\"12\"><br>
Password: <input type=\"password\" name=\"pass_fornita\" size=\"9\"><br>
<input type=\"submit\" name=\"accedi\" value=\"Accedi\">
</form><hr width=\"95%\">
<form  accept-charset=\"utf-8\" method=\"post\" action=\"login.php\">
Nome utente: <input type=\"text\" name=\"nome_utente\" size=\"12\"><br>
Vecchia password: <input type=\"password\" name=\"pass_fornita\" size=\"9\"><br>
Nuova password: <input type=\"password\" name=\"nuova_pass1\" size=\"9\"><br>
Ripeti la nuova password: <input type=\"password\" name=\"nuova_pass2\" size=\"9\"><br>
<input type=\"submit\" name=\"cambia_pass\" value=\"Cambia la password\">
 (non utilizzate una vostra password abituale, la potremo vedere)</form>";


} # fine else if ($cambia_pass)

include("$percorso_cartella_dati/foot.php");
?>
